@@ -14,6 +14,12 @@ geoFence = [
         "box":  ["""35°57'52.6"N 115°09'56.4"W""",
                  """35°57'58.0"N 115°09'49.1"W"""]
     },
+    {
+        "name": "PKSI",
+        "desc": "Swan Island Lot",
+        "box":  ["""45°33'39.8"N 122°42'50.8"W""",
+                 """45°33'46.6"N 122°42'44.0"W"""]
+    },
     {
         "name": "PKBK",
         "desc": "Baker Lot",
@@ -26,6 +32,24 @@ geoFence = [
         "box":  ["""35°10'00.7"N 114°34'09.9"W""",
                  """35°10'17.8"N 114°33'52.9"W"""]
     },
+    {
+        "name": "PKCM",
+        "desc": "Copper Mountain Lot",
+        "box":  ["""39°29'56.2"N 106°08'31.5"W""",
+                 """39°30'15.6"N 106°08'15.6"W"""]
+    },
+    {
+        "name": "SITT",
+        "desc": "Swan Island Test Track",
+        "box":  ["""45°33'50.7"N 122°43'00.3"W""",
+                 """45°33'21.5"N 122°42'01.5"W"""]
+    },
+    {
+        "name": "SIRT",
+        "desc": "Swan Island Regional Testing",
+        "box":  ["""45°33'05.3"N 122°43'06.8"W""",
+                 """45°34'20.7"N 122°41'28.0"W"""]
+    },
     {
         "name": "HSCD",
         "desc": "Hot-Soak Cooldown Prim Loop",
@@ -50,6 +74,24 @@ geoFence = [
         "box":  ["""36°02'18.2"N 115°11'33.6"W""",
                  """35°07'55.2"N 114°32'32.0"W"""]
     },
+    {
+        "name": "TRGJ-CM",
+        "desc": "Grand Junction - Copper Mountain Transit",
+        "box":  ["""38°56'44.9"N 108°44'36.6"W""",
+                 """39°47'55.7"N 106°05'06.3"W"""]
+    },
+    {
+        "name": "TRCM-BR",
+        "desc": "Copper Mountain - Burley Transit",
+        "box":  ["""38°57'24.4"N 106°00'32.8"W""",
+                 """42°36'36.4"N 113°53'29.6"W"""]
+    },
+    {
+        "name": "TRBR-HQ",
+        "desc": "Burley - Portland Transit",
+        "box":  ["""42°33'28.6"N 113°46'35.6"W""",
+                 """45°53'16.4"N 122°55'05.2"W"""]
+    },
     {
         "name": "SL01",
         "desc": "Searchlight Flat Loop",
@@ -91,12 +133,72 @@ geoFence = [
         "desc": "Mesquite Highway Loop",
         "box":  ["""35°57'22.4"N 115°11'19.1"W""",
                  """36°49'47.0"N 114°00'56.4"W"""]
-    }
+    },
+    {
+        "name": "ALT02",
+        "desc": "Eisenhower Loop",
+        "box": ["""39°29'55.6"N 106°09'01.6"W""",
+                """39°41'26.3"N 105°52'56.8"W"""]
+    },
+    {
+        "name": "ALT03",
+        "desc": "Loveland Pass",
+        "box": ["""39°29'55.6"N 106°09'01.6"W""",
+                """39°41'26.3"N 105°51'00.0"W"""]
+    },
+    {
+        "name": "ALT01",
+        "desc": "Winter Park",
+        "box":  ["""39°29'55.6"N 106°09'01.6"W""",
+                 """39°53'55.5"N 105°36'55.4"W"""]
+    },
+    {
+        "name": "FB02",
+        "desc": "Fairbanks to Hilltop",
+        "box": ["""64°47'56.8"N 147°31'33.9"W""",
+                """65°02'38.1"N 147°45'46.3"W"""]
+    },
+    {
+        "name": "FB03",
+        "desc": "Old Nenana Loop",
+        "box": ["""64°47'05.2"N 148°12'43.9"W""",
+                """64°52'32.4"N 147°30'23.8"W"""]
+    },
+    {
+        "name": "FB01",
+        "desc": "Fairbanks to Nenana",
+        "box": ["""64°32'48.6"N 149°08'54.3"W""",
+                """64°53'55.1"N 147°27'56.5"W"""]
+    },
+    {
+        "name": "FB05",
+        "desc": "Fairbanks to North Pole",
+        "box": ["""64°49'29.2"N 147°33'26.3"W""",
+                """64°44'13.6"N 147°17'34.0"W"""]
+    },
+    {
+        "name": "FB04",
+        "desc": "City Loop",
+        "box": ["""64°50'19.4"N 147°35'24.0"W""",
+                """64°43'42.2"N 147°14'48.1"W"""]
+    },
+    {
+        "name": "FB06",
+        "desc": "Fairbanks to Birch Lake",
+        "box": ["""64°49'27.1"N 147°33'29.0"W""",
+                """64°17'52.9"N 146°38'47.2"W"""]
+    },
+    {
+        "name": "FB07",
+        "desc": "Fairbanks to Delta Junction",
+        "box": ["""64°49'26.9"N 147°33'20.8"W""",
+                """64°01'08.0"N 145°41'46.7"W"""]
+    },
 ]
 
 def getGPSBox(listItem:list):
     """
-    Given an input of a list of two items, each being a string containing GPS data in dms N dms W format
+    Given an input of a list of two strings containing GPS data in `dms` N `dms` W format, returns a list of `[west, south, east, north]`.
     """
     if len(listItem[0].split(' ')) != 2 or len(listItem[1].split(' ')) != 2:
         listItem = ["""35°57'52.6"N 115°09'56.4"W""",
@@ -139,18 +241,6 @@ def inGeofence(df:DataFrame, gf:list):
     else:
         return False
 
-def verticalTicks(data):
-    """
-    DEFUNCT
-    """
-    data_max = max(data)
-    data_min = min(data)
-    data_range = data_max - data_min
-    output = []
-    for i in range(0, 5):
-        output.append(round(data_min+i*data_range/5, 5))
-    return output
-
 class Date():
     def __init__(self, month:int=1, day:int=1, year:int=1970):
         self.month = month
@@ -431,7 +521,7 @@ def gps_filter_data(df):
     K1 = 111.13209 - 0.56605 * cos(2 * radians(x_m)) + 0.0012 * cos(4 * radians(x_m))
     K2 = 111.41513 * cos(radians(x_m)) - 0.09455 * cos(3 * radians(x_m)) + 0.00012 * cos(5 * radians(x_m))
     dist = sqrt(square(K1 * dx) + square(K2 * dy)) * 1000
-    keep_dist = dist < 1000
+    keep_dist = dist < 1
 
     # Keep distance under 1km or geofenced into the US
     lat_left, lon_bottom, lat_right, lon_top = [-170, 25, -65, 70]
@@ -461,7 +551,7 @@ def gps_filter_data(df):
     dist = list(sqrt(square(K1 * dx) + square(K2 * dy)) * 1000)
     dist_traveled = [0]
     for i in range(1, len(dist)):
-        dist_traveled.append(round(10*(dist_traveled[i-1]+dist[i]), 0)/10)
+        dist_traveled.append(round(2*(dist_traveled[i-1]+dist[i]), 0)/2)
     dist_traveled[-1] = dist_traveled[len(df)-3]
     dist_traveled.append(dist_traveled[len(df)-3])
     
@@ -734,4 +824,4 @@ def subsetDF(df:DataFrame, signals:list):
     If a requested signal does not exist in the DF, it is omitted from the result.
     """
     signals = [parseName(df.columns, signal) for signal in signals if parseName(df.columns, signal) != -1]
-    return df[signals]
\ No newline at end of file
+    return df[signals]
