@@ -12,9 +12,11 @@ from pvevti import genutil as gu
 from shapely.geometry import Point
 
 #  Parameters
-debugInfo = False
+debugInfo = True
 plt.rcParams['font.family'] = 'Daimler CS'
 default_color_palette = "default"
+IMAGE_CACHE_DIR = None
+GPS_DF_GOAL_LEN = 500
 
 cols = ["#00677F", "#B65302",
         "#7CBCCA", "#0E5A1A",
@@ -464,13 +466,6 @@ default_route_conditions_config = {
                     "plotType": "map",
                     "xData":    "GPS_speed_mph",
                     "yData":    ["gps_x", "gps_y"]
-                },
-                {
-                    "plotTitle":"Ambient pressure & temperature",
-                    "plotType": "dualline",
-                    "xData":    "t",
-                    "yData":    ["amb_p", "amb_t"],
-                    "filterLength": 40
                 }
             ]
         },
@@ -550,6 +545,64 @@ default_route_conditions_config = {
     ]
 }
 
+default_towdyno_config = {
+    "docTitle": "DefaultTowDynoReport",
+    "docSubTitle": "Tow-Dyno Report",
+    "pages": [
+        # 
+        {
+            "pageName": "Route Overview",
+            "plots": [
+                {
+                    "plotTitle":"Trip Route",
+                    "plotType": "map",
+                    "xData":    "GPS_speed_mph",
+                    "yData":    ["gps_x", "gps_y"]
+                }
+            ]
+        },
+        {
+            "pageName": "Retarder Data",
+            "plots": [
+                {
+                    "plotTitle":"Temperatures",
+                    "plotType": "line",
+                    "xData":    "t",
+                    "yData":    ["TC_R1", "TC_R2", "TC_R3", "TC_R4", "TC_R5", "TC_R6"]
+                },
+                {
+                    "plotTitle":"Currents",
+                    "plotType": "line",
+                    "xData":    "t",
+                    "yData":    ["I_R1", "I_R2", "I_R3", "I_R4", "I_R5", "I_R6"]
+                },
+                {
+                    "plotTitle":"Voltages",
+                    "plotType": "line",
+                    "xData":    "t",
+                    "yData":    ["VI_R1", "VI_R2", "VI_R3", "VI_R4", "VI_R5", "VI_R6"]
+                },
+            ]
+        },
+        {
+            "pageName": "Overview",
+            "plots": [
+                {
+                    "plotTitle":"Temperatures & Currents",
+                    "plotType": "table",
+                    "yData":    ["TC_R1", "TC_R2", "TC_R3", "TC_R4", "TC_R5", "TC_R6", "I_R1", "I_R2", "I_R3", "I_R4", "I_R5", "I_R6"]
+                },
+                {
+                    "plotTitle":"Weight",
+                    "plotType": "dualline",
+                    "xData":    "t",
+                    "yData":    ['ctl_weight', 'vehspd_cval']
+                },
+            ]
+        },
+    ]
+}
+
 default_config = {
     "docTitle": "Default Document Title", "docSubTitle": "Default Document Subtitle",
     "pages": [
@@ -1213,29 +1266,99 @@ class Plot:
                 try:
                     p = gdf.plot(
                         ax=ax, markersize=4, column=Series(self.data[0]),
-                        cmap='coolwarm', marker='o', alpha=0.8, legend=True, label='GPS Track',
+                        cmap='turbo', marker='o', alpha=0.8, legend=True, label='GPS Track',
                         legend_kwds={'label': self.columns[0], 'location': 'bottom'}
                     )
+
+                    # Define limits assuming we don't know the route
                     max_x, max_y = max(self.data[1]), max(self.data[2])
                     min_x, min_y = min(self.data[1]), min(self.data[2])
-
                     span_x = max(max_x - min_x, 0.003)
                     mid_x = (max_x + min_x)/2
                     span_y = max(max_y - min_y, 0.003)
                     mid_y = (max_y + min_y)/2
                     span = max(span_x, span_y)*1.1
+
                     p.set_xlim([mid_x-span/1.8,  mid_x+span/1.8])
                     p.set_ylim([mid_y-span/2, mid_y+span/2])
+
                 except Exception as e:
                     print("[{}] Failed to plot data.".format(str(e)))
-                # Attempt to add a Contextily basemap (internet connection reqd.)
+
+                # Attempt to add a Contextily basemap
                 try: 
-                    ctx.add_basemap(ax, crs=gdf.crs.to_string(), source=ctx.providers.OpenStreetMap.Mapnik)
-                    if debugInfo:
-                        print("   Basemap Added!")
+                    # Cut waaaaay down on GPS data (500 sample nominal)
+                    print(" > Current GPS data length: {}\n > Goal GPS data length:    {}".format(len(self.data[0]), GPS_DF_GOAL_LEN))
+                    iteration = max(1, int(len(self.data[0])/max(GPS_DF_GOAL_LEN,1)))
+                    print("    > {} x {} list".format(len(self.data), len(self.data[0])))
+
+                    # Slicing
+                    self.data = [row[0::iteration] for row in self.data]
+                    print("    > {} x {} list".format(len(self.data), len(self.data[0])))
+                    print(" > Stepped GPS data length: {} (step: {})".format(len(self.data[0]), iteration))
+
+                    # Cast small list into dataframe
+                    gps_df = DataFrame({'GPS_x[°]':self.data[1], 'GPS_y[°]':self.data[2]})
+                    print(gps_df)
+
+                    # Acquire GPS Route
+                    print(" > Check route: ", end='')
+                    routename = gu.getRoute(gps_df)[0]
+                    print(routename)
+
+                    # Check if we (a) have access to a cache directory and (b) a route has been found;
+                    # Otherwise, try to download a basemap
+                    mapped = False
+                    if IMAGE_CACHE_DIR and routename != "":
+
+                        # Get all routes
+                        print(" Attempting to add from local")
+                        routes = [file for file in os.listdir(IMAGE_CACHE_DIR) if '.tiff' in file.lower()]
+                        
+                        # Check for the route of interest
+                        if routename+".tiff" in routes:
+                            try:
+                                print("  Found basemade locally!  {}".format(IMAGE_CACHE_DIR+routename+".tiff"))
+                                routenames = [rt['name'] for rt in gu.geoFence]
+
+                                # Get the index of the true route for finding the route object
+                                idx = routenames.index(routename)
+
+                                # Extract the route object
+                                currentRoute = gu.geoFence[idx]
+                                print("    ",currentRoute)
+
+                                # Acquire GPS information and reset bounds to the route's mathcing bounds
+                                [west, south, east, north] = gu.getGPSBox(currentRoute['box'])
+
+                                span = max(east-west, north-south)
+                                span = max(min(span * 1.1, span + 0.1), 0.01)
+                                mid_x = west + (east - west) / 2
+                                mid_y = south + (north - south) / 2
+
+                                ax.set_xlim([mid_x-span/2, mid_x+span/2])
+                                ax.set_ylim([mid_y-span/2, mid_y+span/2])
+
+                                # Get the local file and add the basemap!
+                                print("Pull local file: "+IMAGE_CACHE_DIR+routename+".tiff")
+                                ctx.add_basemap(ax, crs='EPSG:4326', source=IMAGE_CACHE_DIR+routename+".tiff")
+                                
+                                # Confirm that we have in fact mapped it
+                                mapped = True
+
+                            # Catch any issues
+                            except Exception as e:
+                                if debugInfo:
+                                    print("Error when pulling a local file! {}".format(str(e)))
+                    
+                    # If it hasn't been mapped (or there was an issue), download the map from online
+                    if not mapped:
+                        ctx.add_basemap(ax, crs=gdf.crs.to_string(), source=ctx.providers.OpenStreetMap.Mapnik)
+                        if debugInfo:
+                            print("   Basemap Added!")
                 except Exception as e:
                     if debugInfo:
-                        print(f"   Error loading basemap: {e}")
+                        print(f"   Error down/loading basemap: {e}")
                     ax.text(0.5, 0.5, 'Basemap not available!',
                         horizontalalignment='center', verticalalignment='center',
                         transform=ax.transAxes, fontsize=12, color='#7D0000')
@@ -1439,4 +1562,3 @@ def createDocument(df: DataFrame, config: dict, save_path: str=os.path.expanduse
         del cd_page
 
     cd_document.save(save_path)
-
